function [data, param] = dataTransfo()
    %% Grandeurs du modèle
    data = struct('valeur',[],'unite',[""],'description',[""]);
    RowNames = string.empty();
    
    %% Paramètres
    % intialisés avec les valeurs de l'énoncé
    param = struct();
    param.V1 = {230, "V", "Tension au primaire"};
    param.f = {50, "Hz", "Fréquence électrique"};
    param.fp2 = {0.8, "-", "Facteur de puissance au secondaire"};
    param.I2 = {8, "A", "Courant au secondaire"};
    param.Text = {40, "K", "Température extérieure"};
    param.q = {1, "W/kg", "Pertes fer spécifiques"};
    param.kr = {0.5, "-", "Coefficient de remplissage"};
    param.h = {10, "W/m2/K", "Coefficient de convection du réfrigérant"};
    param.lambda_iso = {0.15, "W/m/K", "Conductivité de l’isolant"};
    param.e_iso = {1e-3, "m", "Épaisseur isolant"};
    param.mvfer = {7800, "kg/m3", "Masse volumique du circuit magnétique"};
    param.mvcuivre = {8800, "kg/m3", "Masse volumique du cuivre"};
    param.rho_cu = {1.72e-8, "Ω.m", "Résistivité du cuivre à 0°C"};
    param.alpha_cu = {3.8e-3, "1/K", "Variation de résistivité du conducteur"};
    param.mu0 = {4e-7*pi, "H/m", "Perméabilité magnétique du vide"};
    
    %% Variables de conception
    % intialisées aléatoirement
    
    param.a = {0.0213575896638450, "m", "Largeur latérale du noyau"};
    param.b = {0.0179585689220749, "m", "Hauteur de la fenêtre de bobinage"};
    param.c = {0.0349909557690377, "m", "Largeur de la fenêtre de bobinage"};
    param.d = {0.0800005678988148, "m", "Épaisseur du noyau"};
    param.n1 = {295.042164317853, "-", "Nombre de spires au primaire"};
    param.S1fil = {1.53157548247643e-07, "m2", "Section de câble au primaire"};
    param.S2fil = {4.21219201798017e-06, "m2", "Section de câble au secondaire"};
    
    %% Grandeurs intermédiaires
    % intialisées aléatoirement
    
    param.PJ = {50, "W", "Pertes Joules"};
    param.X2 = {1, "Ω", "Réactance série du bobinage secondaire"};
    param.n2 = {1, "-", "Nombre de spires du bobinage secondaire"};
    param.Pfer = {30, "W", "Pertes fer"};
    param.r1 = {0.5, "Ω", "Résistance électrique du primaire"};
    param.r2 = {0.2, "Ω", "Résistance électrique du secondaire"};
    param.R2 = {0.25, "Ω", "Résistance ramenée au secondaire"};
    param.Bm = {1, "T", "Induction magnétique dans le noyau"};
    param.l1spire = {0.3, "m", "Périmètre d'une spire primaire"};
    param.l2spire = {0.4, "m", "Périmètre d'une spire secondaire"};
    param.Mfer = {5, "kg", "Masse du noyau en fer"};
    param.Mcuivre = {5, "kg", "Masse des bobinages en cuivre"};
    param.Pfer = {5, "W", "Pertes fer"};
    param.Vfer = {1e-3, "m^3", "Volume du noyau"};
    param.Rfercuivre = {1, "m².K/W", "Résistance thermique d'interface fer/cuivre"};
    param.Sferair = {1e-4, "m²", "Surface de l'interface fer/air"};
    param.Rferair = {1, "m².K/W", "Résistance thermique d'interface fer/air"};
    param.Scuivreair = {1e-4, "m²", "Surface de l'interface cuivre/air"};
    param.Rcuivreair = {1, "m².K/W", "Résistance thermique d'interface cuivre/air"};
    param.Lmu = {100, "H", "Inductance magnétisante"};
    param.P1 = {1000, "W", "Puissance active absorbée au primaire"};
    param.Q1 = {100, "VAR", "Puissance réactive fournie au primaire"};
    param.I1 = {80, "A", "Courant au primaire"};
    param.I10 = {0.5, "A", "Courant magnétisant"};
    param.DV2 = {1, "V", "Chute de tension au secondaire"};
    param.V2 = {24, "V", "Tension au secondaire"};
    param.rend = {0.95, "-", "Rendement du transformateur"};
    
    %% Grandeurs de sortie
    % intialisées aléatoirement
    
    %% Objectifs
    
    param.Mtotale = {20, "kg", "Masse totale"};
    param.loss = {0.05, "-", "1 - rendement du transformateur"};
    
    %% Contraintes
    
    param.Tcuivre = {1, "°C", "Température du cuivre"};
    param.Tfer = {40, "°C", "Température du noyau"};
    param.DV2_V2 = {0, "-", "Chute de tension secondaire normalisée / V2"};
    param.I10_I1 = {0, "-", "Courant magnétisant normalisé / I1"};
    param.f2 = {0.45, "-", "Rapport de remplissage du secondaire"};
    param.f1 = {0.5, "-", "Rapport de remplissage du primaire"};
    param.residu = {0, "-", "Résidu"};
    
    
    %% Transformation structure -> table
    
    fields = fieldnames(param);
    for i = 1:length(fields)
        RowNames(i,1) = fields{i};
        data.valeur(i,1) = param.(fields{i}){1};
        data.unite(i,1) = param.(fields{i}){2};
        data.description(i,1) = param.(fields{i}){3};
    end
    data = struct2table(data);
    data.Properties.RowNames = RowNames;
    data = sortrows(data,"RowNames");
    end