function [residual,Jacobian] = sysEquation(conceptionVariables,parameters,innerState)
        %% Inner model function 
        % Returns the residual (n,1) and the jacobian of the system (n,n)
        % Needs to have all input as (m,1) vectors not (1,m) 
        %% Check if the vector are column vector and not line ... 
        if size(innerState,2) ~= 1 
            error("ERROR: InnerState is not a column vector"); 
        end
        if size(conceptionVariables,2) ~= 1 
            error("ERROR: conceptionVariables is not a column vector"); 
        end
        if size(parameters,2) ~= 1 
            error("ERROR: parameters is not a column vector"); 
        end

        %% Constants
        muo = 4*pi*1e-7;

        %% Unpack conception variables, parameters and innerState (Order is important !!)
        innerState = num2cell(innerState);
        [r2,X2,n2,DV2,Pj,Tcuivre,r1,R2] =  innerState{:};
        conceptionVariables = num2cell(conceptionVariables);
        [a,b,c,d,n1,S1fil,S2fil] = conceptionVariables{:};
        parameters = num2cell(parameters);
        [V2,V1,f,fp2,I2,Text,q,~,h,lambda,e_iso,mvfer,~,rhocuivre,alphacuivre] = parameters{:};

        %% Compound quantities 
        l2spire = 2*(d+2*a)+pi*3*c/2;
        Bm = 1/4*V1*sqrt(2)/(n1*a*d*pi*f);
        l1spire = 2*(d+2*a)+pi*c/2;
        Mfer = 4*a*d*(2*a+b+c)*mvfer;
        Pfer = q*Mfer*f/50*(Bm/1)^2;
        Rfercuivre = e_iso/(lambda*b*(4*a+2*d));
        Sferair = 4*a*(4*a+b+2*c)+2*d*(6*a+b+2*c);
        Rferair = 1/(h*Sferair);
        Scuivreair = b*(4*a+2*pi*c);
        Rcuivreair = 1/(h*Scuivreair);
        
        %% Residual of the implicit system (8 equations)
        residual(1) = r2 - rhocuivre*(1+alphacuivre*Tcuivre)*n2*l2spire/S2fil;
        residual(2) = X2 - 1/3*muo*n2^2*c*(4*a+2*d+pi*c)/b*2*pi*f;
        residual(3) = n2 - n1*(V2+DV2)/V1;
        residual(4) = DV2 - (R2*fp2+X2*sin(acos(fp2)))*I2;
        residual(5) = Pj - R2*I2^2;
        residual(6) = Tcuivre - Text-Rcuivreair*(Rferair*Pfer+(Rferair+Rfercuivre)*Pj)/(Rcuivreair+Rferair+Rfercuivre);
        residual(7) = r1 - rhocuivre*(1+alphacuivre*Tcuivre)*n1*l1spire/S1fil;
        residual(8) = R2 - r2-(n2/n1)^2*r1;
        residual = residual(:);
        
        %% Jacobian operator of the implicit system
            
        Jacobian = [1, 0, -rhocuivre*(1+alphacuivre*Tcuivre)*l2spire/S2fil, 0, 0, -rhocuivre*alphacuivre*n2*l2spire/S2fil, 0, 0;
                    0, 1, -4/3*muo*n2*c*(4*a+2*d+pi*c)*pi*f/b, 0, 0, 0, 0, 0;
                    0, 0, 1, -n1/V1, 0, 0, 0, 0;
                    0, -sin(acos(fp2))*I2, 0, 1, 0, 0, 0, -fp2*I2;
                    0, 0, 0, 0, 1, 0, 0, -I2^2;
                    0, 0, 0, 0, -Rcuivreair*(Rferair+Rfercuivre)/(Rcuivreair+Rferair+Rfercuivre), 1, 0, 0;
                    0, 0, 0, 0, 0, -rhocuivre*alphacuivre*n1*l1spire/S1fil, 1, 0;
                    -1, 0, -2*n2/n1^2*r1, 0, 0, 0, -n2^2/n1^2, 1];
            
        
    end